@@ -92,6 +92,27 @@ contr.metric <- function (n, contrasts = TRUE) {
   cont
 }
 
+#' scaler
+#'
+#' @description Returns a scaled data.frame.
+#'
+#' @param df A data.frame only with numeric variables.
+#'
+#' @return A data.frame.
+#'
+#' @export scaler
+#'
+scaler <- function (df) {
+  m <- apply(df, 2, mean)
+  s <- apply(df, 2, sd)
+
+  return(list(
+    "apl"   = function(x) data.frame(t((t(x) - m) / s)),
+    "inv"   = function(x) data.frame(t((t(x) * s) + m)),
+    "invar" = function(x, v) x * s[v] + m[v]
+  ))
+}
+
 #' max_col
 #'
 #' @keywords internal
